#
# spec file for package fate
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define baseversion 1.6
%define patchlevel .0.5
%define snapshot 20180525-4ba98756
Name:           fate
Version:        %{baseversion}%{patchlevel}
Release:        36.12
Summary:        SUSE Feature Management Tool
License:        GPL-2.0-only OR GPL-3.0-only OR LGPL-2.1-or-later
Group:          Productivity/Office/Other
Url:            http://inttools.suse.de
Source0:        fate-%{snapshot}.tar.bz2
Source1:        mkdist
Source2:        update
BuildRequires:  cmake >= 2.8
BuildRequires:  libctemplate-devel
BuildRequires:  libkde4-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  pkgconfig
BuildRequires:  sqlite-devel
Requires:       kdebase4-runtime
Requires:       oxygen-icon-theme
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1010
Recommends:     diffutils
Recommends:     sxtopdf >= 0.5.7
%endif
%if 0%{?suse_version} > 1220
Requires:       iceauth
%endif

%description
Fate is the client for the SUSE Feature Management database. It
provides views on the feature data and allows to query and edit them.

%prep
%setup -q -n fate-%{snapshot}

%build
make clean

export SUSE_ASNEEDED=0
export CFLAGS="${optflags}"
export CMAKE_INSTALL_PREFIX=%{_prefix}

make %{?_smp_mflags}

%install
export SUSE_ASNEEDED=0
%make_install

%files
%defattr(-,root,root)
%{_bindir}/fate
%{_datadir}/doc/kde/HTML/en/fate
%{_datadir}/kde4/apps/fate
%{_datadir}/kde4/services/fate.protocol
%{_datadir}/applications/fate.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/fate.svgz

%changelog
* Fri May 25 2018 joachim@suse.de
- remove own old definition of CHECK_CXX_SYMBOL_EXISTS to compile
  again with cmake 3.11+
* Thu May 24 2018 jplack@suse.com
- bugfix release 1.6.0.5
  * fix #1094520 - New or imported features are sometimes not
  shown/editable, thanks to Dwain Sims
  * fix #1081921 - explicitely select feature if it is the first one
  * enhanced ECO approver handling
  * implement adding of single ECO approver
  * fix #1080586 - Misleading label in ECO form
  * fix #1088478 - Prefs can have invalid Products, thanks to Adam Majer
  * integrate experimental list and tree view (sparetime project) to
    help SLE12SP4 business value process experiment
  * make some space in PriorityTable for context menu to select
  * give additional productid for each approver for each diff or history
  * include caching of productId for ECO approvers
* Fri Dec  8 2017 jplack@suse.com
- bugfix release 1.6.0.4
  * fix #1071535 - Prio P1: Changes to Dev/QA in ECO tab are not recognized or saved
  * fix #962999  - CSS: Font size 8pt too small for reading
  * fix #1059515 - Fate repeatedly crashing
  * fix #1054023 - Can change ECO fields after initial save
  * fix #1047302 - Duplicated features not visible in FATE
  * fix #984459  - Crash after not saving new entry and quitting
* Mon Aug 14 2017 jplack@suse.com
- bugfix release 1.6.0.3
  * fix #1049390 - Standard approvers are not prepopulated anymore in ECOs
  * fix #1052788 - attachments are accepted , but not added / referenced
  * fix #1053025 - Crash when trying to approve an ECO
  * fix #1052391 - Cannot add Engineering Manager
  * fix #1052799 - Cannot change Priority
* Mon Jul 31 2017 jplack@suse.com
- bugfix release 1.6.0.2
  * fix bsc#1050997 in query by ids, thanks to reporter afaerber@
    and aschwab@
  * fix freeze/unfreeze in FeatureTableView
  * do not copy xml representation in Feature::operator=
  * eliminate public method FeatureMap::recordChange that nobody needs
  * FeatureMapListView: derive directly from FeatureTableView
  * fix reloading of single features, eliminate signal
    FeatureMap::featureReloaded()
  * let FeatureView handle its stuff alone in MainView
  * handle signals from FeatureMap properly in FeatureView if they apply
  * add a new public method FeatureMap::addNewFeature, making
    addFeature/addFeatures protected
  * hide progress bar after Feature import or cloning
  * make Feature::operator= an internal operation for friend classes only
  * do not bail out on new Features in FeatureDiffView::showFeatureChanges
  * remove non-emitted signal FeatureDisplay::featureSelected(Feature*)
  * remove FeatureMap* from FeatureView constructor
  * fix bug in Feature::operator=
* Tue Jun 27 2017 jplack@suse.com
- bugfix: bring back signal FeatureMap::featureReloaded
* Fri Jun 23 2017 jplack@suse.com
- bugfix release 1.6.0.1
  * bsc#1044954 FATE crashes on selected feature in query (TumbleWeed only)
* Thu Jun  8 2017 jplack@suse.com
- update to version 1.6
  * override the productName in features with the one from the database
    if available
  * remove "show Document Source" functionality nobody really needs
- Easier workflow fo Save/SaveAll features (bsc#1036753):
  * add save actions w/ kbd shortcuts to separate FeatureViews
  * add save actions to menues and tool bars
  * Fix naming for explicit number queries
  * adding actions for save_feature and save_all_features to FeatureView
  * change Query shortcut from Ctrl-S to Ctrl-F
- Multiple changes at once:
  * distinguish between updateProduct and addProduct in
    PriorityTable::updateProductData
  * change editable flag of requester prio dynamically in PriorityTable
  * always keep old values in PriorityTable
  * avoid usage of QSignalMapper in PriorityTable
  * use Feature::updateProduct in PriorityTable
  * implement MultiFeature::updateProduct
  * implement Feature::updateProduct()
  * move down PriorityTable::addAsRequester() for newly added products to
    class Feature
  * pass a real list in Feature::products() instead of a const reference
  * pass a real list of actors up instead of a reference so that the compiler
    does not optimize in multifeature
  * use class MultiOpView in FeatureView
  * implement class MultiOpView
  * implement class MultiFeature
  * avoid excess signals in Feature::removeProduct
  * implement Priority::operator=
- Use class FeatureViewBase wherever appropriate:
  * SimpleEditor, more use of macro FeatureViewBase_setFeature
  * derive SimpleEditor from FeatureViewBase
  * also disconnect the other way round in FeatureViewBase_setFeature
  * prepare Simpleeditor for using FeatureViewBase
  * remove acccess includes in ecoeditor.cpp
  * include verticalpage.h directly for ecoeditor
  * split out VerticalPage from simpleeditor into separate files
  * use FVB extension in EcoEditor, PriorityTable, FeatureDisplay,
    FeatureDiffView and FeatureActorEdit
  * derive class FeatureView from FeatureViewBase
  * extend class FeatureViewBase
- Enhance presenting Diffs (bsc#1039533 and more):
  * dimm green and red by 10%% used for presenting changed lines in
    FeatureViewDiff
  * use monospaced font for presenting diffs
- Simpleeditor:
  * refactor to use new class Feature signals
  * avoid cursor position reset (wrong feedback from Feature) when editing in
    QLineEdit
  * use QLineEdit instead of KLineEdit
  * fix richtext conversion in all RichTextEdit widgets, report from
    behlert@suse.de
- Multiple FeatureView windows:
  * set default size 800x600 for newFeatureView
  * fix crash when calling context menu outside of table
  * fix crashes on reload of the feature
  * open new window on signal requestFeatureView in MainView
  * implement a context menu just to signal a requestFeatureView(Feature *)
  * implement class FateTableWidget to avoid selection on right mouse button
    click
  * remove obsoleted slot FeatureTableView::updateTitle
  * make ProductMap a singleton class and use it in FeatureView, EcoEditor,
    PriorityTable, ApproverListEdit, SimpleEditor, MainView
  * added TODO comments about what needs to be done
  * update signal connections to FeatureView
  * eliminate MainView::selectFeature() only used once
  * for initial feature selection also highlight it in FeatureListView
  * add helpful coments to mainview.cpp
  * remove FeatureView::save() finally
- Make ECO code compliant to refactored class feature
  * avoid warnings from early translation
  * fix FeatureView::startECO
  * signal modified moved from VerticalPage where it disappeared
  * remove duplicated code and fix wrong usage of derived virtual methods
  * eliminate obsolete FeatureView::saveData()
  * transform EcoEditor to derive from FeatureViewBase
  * implement signal Feature::saveECO()
- Refactor SimpleEditor to use new signals of class Feature:
  * fix problems saving single modified feature (email report from
    Matthias Eckermann)
  * implement FeatureDisplay::updateView for obvious reasons
  * comment out currentFeatureAboutToBeSaved
  * remove connects to deprecated signal modified()
  * remove FeatureView::slotTitleChanged
  * remove obsoleted code and declarations
  * FeatureView: no more need to actively update other widgets
  * remove modified signals, slots and flag, class Feature keeps state
  * remove signal titleChanged, class Feature has it now
  * remove signal titleChanged() form FeatureView which now comes from Feature
  * remove no longer needed method saveData(bool)
  * use-feature-signals for ReleaseNotesPage, InternalPage, MiscPage,
    PartnerPage, GeneralPage
  * get independent from definitions of documentationStatus in FeatureData
  * remove dead, commented or debug code
  * RichtextEditor: implement signal textEdited(s), make setPlainText a slot
  * RichtextEditor: update copyright notice
- New product&priority editor:
  * update feature data model when deleting a single product in PriorityTable
  * fix unintended changes of feature in PriorityTable::setArch
  * add completion to PriorityTable::addAsRequester
  * priorityTable: remove warnings
  * transform PriorityTable to derive from FeatureViewBase
  * eliminate PriorityTable::clear
  * show milestone column only when needed
  * cleanup PriorityTable::addProduct
  * remove passthrough slot for priorityTable
  * get confusing column and row out of the names, use product_ix and attribute
    instead
  * remove scrollbarpolicy that is without effect
  * delete unused archeditor
  * cleanup debug and warning messages
  * split out common code from changeProduct and editProduct to method void
    changeProduct(int, QString);
  * rename editProduct to editSingleProduct, be less confusing same with
    addProduct(void) to slotAddProduct
  * prioritytable: simplify and clean code a bit
  * prepare for extended status handling
  * fix status tooltip and add for duplicates and products cleanup status
    handling
  * eliminate mEditing, setEnabled() is enough
  * also add products through product pulldown
  * add tooltips to row headers
  * removed always hidden duplicateRow and unsuse TableCol enum
  * create a popup QMenu for editing single products
  * simplify setXX functions, delete unused
  * pass generalpage in constructor of PriorityTable
  * eliminate slotEditProductList()
  * simplyfy code and loops, heavy use of foreach macro
  * disable text editing of product name item
  * adjust style for comboboxes
  * remove KDE3 #if remainders
  * Convert  mEntries to be a QList<Entry>
  * prioritytable: implement size hints and resize handling
  * derive PriorityTable directly from QTableWidget
  * remove unused sort function
  * remember products by name rather than id
  * eliminate productlisteditorbase
  * exchange order of PrjMgr and PM, PM first
  * edit architectures through QxtCheckComboBox now
  * simplyfy setComboItem and use it where possible
  * Turn priority dialog by 90 degrees
- New ActorList Editor:
  * Merge branch 'new-actorlist-editor'
  * fix item association in ActorListEdit::showActorMenu
  * highlist role when it contains yourself
  * use FeatureActorEdit instead of ActorListEdit in GeneralPage
  * commentDialog acts directly on Feature object
  * implement class FeatureActorEdit as a FeatureViewBase wrapper around
    ActorListEdit
  * enable context menu on left click as well
  * remove Delete shortcut from ListEdit which does not work as the action
    needs to be added to a global widget
  * fix updating of display
  * fix functionality when roleHidden is set
  * fix crash in removeActor
  * fix layout for other dialogs using ActorListEdit
  * updateView is virtual
  * use SIGNAL ActorListEdit::actorsEdited in simpleeditor
  * implement ActorListEdit::showActorMenu
  * implement ActorListEdit::slotAddMyself(QString roleId) and heavily use it
  * remove all radio and check boxes from ActorEditor
  * remove debugging messages
  * refine layout mgmt for ActorListEdit
  * implement ActorListEdit::sizeHint() and minimumSizeHint()
  * remove commented broken code
  * nicer name list and tooltip
  * make sure the list has the requester first, followed by ProdMgr
  * remove remaining KDE deps
  * make slotXXitem methods work again
  * let addActor(QSharedActor *) handle duplicates
  * add another findRow(QSharedActor*) method
  * fix setToolTip and move into updateView
  * remove unused ActorListEdit::actorUpdated(), adjust removeActor methods
  * First stage: - exchanged role and person column which now contains a list of
    all person in that role - loading and storing of the data works - all slots
    need testing/adjusting
  * use Actor::displayName() in eco.cpp, remove unused static method
  * ListEdit: enhance layout management and reimplement removeRow() for that
  * ListEdit: sizeHint() is virtual
  * ListEdit: remove unused kDebug
  * implemented ListEdit::insertRow() methods
  * remove unused stuff, eliminate roleHidden and listView in ActorListEdit
  * adjust ListEdit's sizePolicy
  * deprecate ListEdit::listView()
  * choose a nicer label for roles and actors
  * fix toolTips using Qt4 style finally
  * implement signal actorsEdited() replacing signal modified() and make
    setActors() a slot
- Configurable tabbed FeatureView:
  * some tuning for FeatureDiffView
  * better default tabs in FeatureView
  * add a placeholder for a multiOperation widget
  * initialize newly added FeatureViewBase tab with current feature data
  * FeatureDiffView: keep config over restart
  * implement FeatureDiffView::setFeature(Feature *), eliminate diff() and
    showDiff()
  * implement FeatureDiffView::configure (dialog)
  * transform FeatureDiffView to derive from FeatureViewBase
  * transform FeatureDisplay to derive from FeatureViewBase
  * implement class FeatureViewBase
  * adjust CMakeLists.txt and editor/featurediffview* to compile again in the
    new location
  * mv ui/diffgenerator to editor/featurediffview
  * use new FeatureDiffView in FeatureView
  * transform DiffGenerator to class FeatureDiffView
  * replace FeatureMap::showDiff dialog by the data provider origFeature()
  * show ECO tab when selected feature has an ECO section
  * remove all bottom buttons in ECOEditor, SimpleEditor and FeatureDisplay
  * implement configurable QTabWidget w/ all bottom buttons in a QMenu
- Eliminate use of some KDE widgets including KTabWidget
  * directly derive FeatureView from QTabWidget, eliminate KTabWidget
  * SimpleEditor: port from KTabWidget -> QTabWidget
  * directly derive ECOEditor from QTabWidget
  * MainView: better icons for reload actions
  * MainView: port from KTabWidget -> QTabWidget
  * use class RelationTreeMap as a singleton class
  * reduce usage of KLineEdit
  * replace KTextEdit
  * replace KPushButton
- Refactor class Feature model alike
  * simplify Feature::productByName
  * Do not allow duplicate actors (bsc#961147)
  * Feature::addProduct() does now also work for update
  * implement Feature::removeProduct(const QString &id)
  * implement ProductContext::operator=
  * add architecture strings to featuredata
  * fix FeatureData::Actor::match to handle empty identity special and not as a
    catchall wildcard
  * make FeatureData::Actor::operator= and operator!= const
  * adding FeatureData::Actor::displayName() and Actor::displayEmail()
  * feature: export assigned featureMap
  * avoid crash on destruction of HtmlView
  * do not use intelligent setter functions while parsing feature
  * update copyright notice, fold long lines
  * feature: optimize/minimize emitting of signals
  * feature: remove unused method removeActorRole()
  * feature: simplify code
  * featuremap: pass through signal Feature::featureChanged()
  * implemented Feature::operator=
  * make handling of documentationStatus in FeatureData case insensitive, return
    upcase-first strings
  * implement emitting of signals
  * make class Feature a decendent of QObject
  * make setter methods public slots for class Feature
  * remove unused methods from class Feature
  * remove or comment support for feature tagging/voting, disable code compilation
  * removed support for unused feature element 'effort'
- Also resolves bugzillas:
  * bsc#887741  normal quit of fate client triggers KCrash
  * bsc#961147  Duplicate Person Box
  * bsc#1024737 FATE: Does not show up in menu
  * bsc#1032240 Segfault when removing Info Provider
  * bsc#1036753 Two clicks required to save a FATE entry
  * bsc#1032321 No save button after changing product
  * bsc#1032481 Unable to save a feature
  * bsc#1040654 Rename SLE-13-HPC to SLE-15-HPC
* Thu Jun  8 2017 jplack@suse.com
- test build of version 1.6
* Thu Mar 16 2017 jplack@suse.com
- limit query title label to a single line, EMail bug from Kai Dupke
* Tue Mar  7 2017 jplack@suse.com
- remove dependency to libBoost, contribution from Michael Matz
* Mon Mar  6 2017 jplack@suse.com
- update to version 1.5.5.8
  * bsc#1028004: Error when generating a query that uses milestones
  * remember DeltaDialog size over restart
  * make diffs in 'Changes' dialog coloured
* Fri Feb 10 2017 jplack@suse.com
- weekend update, pl2 ;-)
  * the mouse wheel is now (better) usable in the general tab of
    the feature editor
  * better label for priority editor table
  * bsc#1024737: update fate.desktop file to have official menu
    categories listed
* Tue Jan 31 2017 jplack@suse.com
- replaces outdated inttools@ mail adress by featureadmin@ (bug via email)
* Sat Jan 28 2017 jplack@suse.com
- more fixes:
  * bsc#837526: fix filter in productviewer, rearrange columns and layout,
    also show feature open dates and deadlines
  * bsc#964882: fix crash, QList::first() returns undefined on empty list, so
    check first
* Thu Jan 26 2017 jplack@suse.com
- update to version 1.5.5.7
  * make comments always editable by original author
  * bsc#1006192: have UTC time stamps in comments as in openfate
  * bsc#940928: fix formatting and limit comment threads
  * bsc#967367: remove bookmarks feature which is currently broken
  * bsc#1004536 : create an extra list for ECO stakeholders in feature view
* Tue Jan 24 2017 jplack@suse.com
- removed old style 'norootforbuild'
- require oxygen-icon-theme instead of oxygen5-icon-theme (bsc#1015881)
* Thu Jan 19 2017 jplack@suse.com
- update to version 1.5.5.6
  * make fate.spec clean for "spec-cleaner"
  * cleanup of cmakefiles, adapting to current style and syntax with much help
    from Tomas Chvatal
  * removed code for unused query-history tracking
  * replace deprecated code from qt3 compatability remaining from last port
  * remove code for unused tagging and voting
  * clean old outdated comments/code from specfile, use new Makefile
  * included patches from dmolkentin to fix fate process help view
  * switched to using repo on new gitlab.suse.de, adjusted update script
  * fix ProgressWidget as a final step away from Qt3 remainders
  * fixes BSC#980276, #978153, #956270, #1004536, #957827, #934673
  * fixes 8+ years old bsc#401198: Saving changes list of displayed features
* Thu Dec 15 2016 joachim@suse.de
- added requirement for oxygen5-icon-theme (bsc#980276)
* Mon Mar 21 2016 jplack@suse.de
- update to version 1.5.5.5
  * add editing person as additional requester when he adds a new
    product to the feature
* Fri Feb 26 2016 joachim@suse.de
- update to version 1.5.5.4
  * prioritytable: reenable editing of requester prio by himself
* Thu Feb 25 2016 joachim@suse.de
- update to version 1.5.5.3
  * replace splitter by scrollbars in simpleeditor&ecoeditor
  * give more space for labels in VerticalPage
  * eco editor: move long labels to be tool tips and give short labels instead
  * add optional toolTip to RichTextEditors in VerticalPage
  * implement ListEdit::sizeHint()
  * richtexteditor: fix/adjust layout
  * prioritytable: fix/adjust layout
  * prioritytable: make sure requester prio is not editable
* Tue Feb  9 2016 jplack@suse.de
- update to version 1.5.5.2
- add new build dep to build with newer libboost v1.60+
- fixes BSC#962053, #964836
* Thu Dec 17 2015 joachim@suse.de
- update to version 1.5.5.1
  which fixes BSC#957386
  points to bugzilla.suse.com instead of bugs.kde.or
* Fri Nov 20 2015 joachim@suse.de
- update to version 1.5.5
  which fixes the following BSCs and more
    [#937337] 	Current fate version 1.5.4 not available in Bugzilla
    [#934672] 	Version 1.5.4 is missing in the selection list ;-)
    [#924455] 	Adjustment in "default approvals" on ECOs against released products
    [#907293] 	Upload of documents does not work, error 455
    [#940055] 	@microfocus email aren't recognized as "internal" email
    [#917101] 	/FList/ sort ordering of numeric feature IDs is alphabetical
    [#930132] 	"show documentation" button on first time setup screen does nothing
    [#359579] 	Click below a combo box will select the item
    [#863488] 	Edit sections can disappear
    [#886374] 	Error: TPM-Priority must be empty
    [#889548] 	Improving Fate Workflow
    [#846030] 	Documentation for Release Notes ready to merge
    [#683452] 	doc-impact and category Documentation should be interconnected
    [#834823] 	/Relations/ adding relation type url always erases the url
    [#743587] 	/Relations/ editing novell/bugzilla/id removes the bugzilla id
    [#631460] 	/Relations/ Bugzilla ID in relations resets to zero
    [#848282] 	FATE did not update list_approvers
    [#954953] 	/ECO/ ecoapprovers format set wrong by feature parser
  plus some support for BSCs#939788, #913038, #943048
- new display for comments, dimming down longish unproductive discussions
- compactify general feature display to fit more on one page enabling to be
  more productive with the fate client
- phase out relation type novell/bugzilla/id
- fix bug in querydialog, wrong/misleading error msg/warning
- lots of small internal stability fixes
* Tue May 26 2015 jplack@suse.de
- update to version 1.5.4
  which fixes the following BSCs and more
  [#915184]    Fate crashes clicking 'new feature'
  [#899494]    "active product" on reload not re-set
  [#902672]    Setting "Active products" to 'none' results in status for
  first or more feature not being cleared
  [#899491]    state for features sometimes not shown correctly
  [#931484]    New features results in a segfault
* Tue Mar 31 2015 jplack@suse.de
- fix relationtree creation
    BSC#913206    Can't save newly created relation tree
* Tue Mar 31 2015 jplack@suse.de
- fix problems introduce by going to KDE4 and its slightly different
  KDialog widget
* Tue Mar 24 2015 jplack@suse.de
- fix problems in saving attachments
* Thu Feb 19 2015 jplack@suse.de
- bump internal version to 1.5.3 as well
* Thu Feb  5 2015 joachim@suse.de
- update to version 1.5.3
* Tue Feb  3 2015 jplack@suse.de
- some bugfixes, ready for release ...
* Sat Dec 13 2014 jplack@suse.de
- bugfix: wrong order for short feature status
- preparation for next production release
* Tue Dec  9 2014 jplack@suse.de
- merged branch 'actorcache' by okir@suse.de
- merged branch 'mainwindow-sizes' by okir@suse.de
* Tue Dec  9 2014 jplack@suse.de
- avoid automatic loading of missing features of currently selected relationtree
* Tue Oct 28 2014 jplack@suse.de
- integrating latest cleanups
* Mon Sep 29 2014 jplack@suse.de
- fix ExportDialog esp. error handling avoiding empty/illegal output file names
- trim the code above to the minimum needed deleting completely unused parts
* Mon Sep 29 2014 jplack@suse.de
- make newfeaturedialog work with new KDialog again
- guessTitle does not alter object so call it 'const'
* Fri Sep 26 2014 jplack@suse.de
- replacing all Novell references to being at fully SUSE BU related thing :-)
- fixing set default priority action for new features
* Tue Sep 16 2014 jplack@suse.de
- first implementation of product specific feature status visualization in FeatureTableView
* Tue Sep  9 2014 jplack@suse.de
- moving productList generation into FeatureMap class ready for reuse
* Fri Sep  5 2014 jplack@suse.de
- remove broken query history move actions
- some reordering for query actions based on reported usage
- avoid empty xquery on empty actor string input
- fill milestones with any,none in all cases
* Tue Sep  2 2014 jplack@suse.de
- forgot to removed debug code
* Tue Sep  2 2014 jplack@suse.de
- adding and using new checkable combobox for status selection
- adding convenience button for direct apply xquery and edit it.
- some more nice changed to the custom query dialog
- bumped to version 1.5.2.2
* Mon Sep  1 2014 jplack@suse.de
- remove dependeny to python-kde4-khtml as it does not seemed to be
  needed but is a hassle for SLE12
* Tue Aug 19 2014 jplack@suse.de
- a couple of updates, simplifications and cleanup for the
  create-query dialog
* Thu Jul 31 2014 jplack@suse.de
- first iteration of a new create-query dialog
* Thu Jul 17 2014 jplack@suse.de
- added scripts mkdist and update to please validity checkers
* Tue Jul 15 2014 jplack@suse.de
- Final additions into 1.5.2
- reformulate the slotEditAppover method to match the slot method of
  the super class (bnc#862363)
- setting minimum window size to 800x600 (bnc#848989)
- adding QtCore Includes for post-13.1 builds
* Fri Jul 11 2014 jplack@suse.de
- adjust the License so it hopefully builds under SLE-12
* Thu Jul 10 2014 jplack@suse.de
- adding save/diff buttons to EcoEditor Tab (bnc#886254)
* Tue Jul  8 2014 jplack@suse.de
- finally found out how to alter automatic menus
* Mon Jul  7 2014 jplack@suse.de
- Going to version 1.5.2
  Enhance and add list of queriable fields (bnc#701518)
  Remove query history from menu bar (bnc#885743)
* Fri Jul  4 2014 jplack@suse.de
- assign explicit accelerators to Tabs (bnc#862116)
* Mon Jun 16 2014 jplack@suse.de
- fixed ReadOnly mode and clientinfo handling
* Thu Jun  5 2014 jplack@suse.de
- Adding mkspec, updating meta data, checking build
* Thu Dec 19 2013 okir@suse.com
- Adding support for architecture ppc64le
* Wed Nov 13 2013 mpost@suse.com
- Bumped the version number in src/version.h to 1.5.1 so that the
  client would stop nagging to be upgraded.
* Thu Oct 31 2013 okir@suse.com
- Fixed a few compile warnings
* Mon Oct 28 2013 okir@suse.com
- Releasing 20131028-72b693b as fate 1.5.1
  * ApprovalListEdit: add hack to remove extraneous approvals
  * The tagging dialog was not displaying properly (bnc#843209)
  * FeatureTableView: allow filtering by ID in addition to Title (bnc#841972)
  * Automatically convert ECOs in intermediate format to new format
  * Fix the editItem slot in the relation ListEdit
* Thu Sep 19 2013 okir@suse.com
- Update to the new KDE4 based FATE client with ECO support.
* Fri Aug 24 2012 mge@suse.com
- default to keeper.suse.com
* Wed Nov 16 2011 aduffeck@suse.com
- fix build on 12.1
* Fri Jul  1 2011 tschmidt@suse.de
- Added validation state patch from bnc#697528
* Tue Feb 22 2011 aduffeck@novell.com
- Add support for the new release notes tag
* Tue Aug 10 2010 mge@novell.com
- Fate 1.4.2pre
- Reintroduce "categories" to the fat client: "tags" do not serve
  the purpose they are supposed to do. Specifically "tags" can't
  be searched properly via XPath.
- allow to apply one person to all roles
- Layout change:
  o Normalize screen layout and improve usability:
    all "Tabs" ar on the top now (reduce mouse movement)
  o Rename "Partner" to "Cases"
  o Rename "Miscellaneous" to "Misc"
- Improve usability for searching from the main window.
* Wed Aug  4 2010 jw@novell.com
- Fate 1.4.2jw
  compiled an svn snapshot, using libctemplate-devel which seems to be
  compatible with google/template*, except for a changed namespace.
  Added SUSE_ASNEEDED=0 to make the linker reorder libraries as needed.
  FIXME: libfateui.a needs -lxslt which is too early on the list.
* Wed Feb 25 2009 aduffeck@suse.de
- Fate 1.4.1
- Hide "Test server" button and set correct default button.
- align numbers to the right
  feature#305079
- look for lowercase emails and userid
  bnc#412478
- get rid of "QGArray::find: Index 0 out of range" messages
- Encapsulate the fancy combobox in FateComboBox. Also use it for the
  relation trees
- do not allow duplicate actors
  bnc#418062
- do not eat links with ampersands
- allow to start fate with a list of features to be queried
- make the items in the FateComboBox groupable. That means that they will
  be sorted in groups (e.g. public and private trees)
- fix escaped urls
- add 'skip-meta-checks' option for skipping the md5sum checks on meta files
- relation trees
  fate#303632
- Make the openSUSE.org partner more prominent by offering two options:
  - openSUSE.org
  - other partner
  bnc#417624
- replace html chars
  bnc#467006
- add a shortcut for the role-combo and fix a bug where the label was always hidden
  bnc#471374
- fix false md5sum positives
  bnc#410102
- allow to copy email addresses and urls (rightclick->copy)
  bnc#417235
- remove feature/duplicate from the editable list of relations
  bnc#397257
- import the fullname of actors in Bugzilla import
* Tue Sep  2 2008 aduffeck@suse.de
- Fate 1.4.0.3
- Fix escaping of queries, e.g. when querying for "IS&T"
- Enhance usability of the actor dialog
- Allow to start fate with a comma separated list of feature ids,
  which should be queried (which is needed for the Fate-Watcher
  plasmoid)
- fix parsing of URLs in comments
* Thu Jul 24 2008 aduffeck@suse.de
- Fate 1.4.0.2
- Fix crash with disabled caches. bnc399007
- Only validate features that are about to be saved
* Wed Jul 23 2008 aduffeck@suse.de
- Fate 1.4.0.1
- Fix PDF Export for features with utf8-chars
- Allow changing only the role of an actor. bnc410326
- Disable the widgets of the inactive product query option
* Wed Jul 16 2008 aduffeck@suse.de
- Fate 1.4
- make the relation title mandatory
  bnc397263
- check for empty fields in the relation editor
  bnc398396
- Add a "Insert myself as x" option based on the user role
  fate304523
- better documentation
- add a non-interactive SaveAllDialog for better feedback when several features are being saved
- allow to cancel the save process
- show the error details in the dialog before asking if the user wants to continue
- automagically close the non-interactive SaveAllDialog when there is nothing left to do
- increment schema revision
- also exclude "tested" with the "no inactive features" option
- better label for the "no inactive features" option
- add shortcut for "New Feature". Patch by Gerald.
- add usernames to xslts
- adapt "My Features" query to new schema
- Switch order of Implementation and Ready in some further places.
  Use current nomenclature (project manager, engineering manager).
  Also include PMs for this exercise and make them responsible for status New instead of PrjMgrs.  Patch by Gerald.
- autocompletion for username and fullname lineedits
- fix actor query
- fix duplicate detection
- make sure that the buttons are shown in the comment dialog
  bnc400492
- Ask the user if he really wants to re-reject.
  bnc401900
- print "no priority" if there is no priority
  bnc#401877
- detect <br/> tags
  bnc402067
- add missing requires
- use dbxml:contains, which offers case-insensitive search
- adapt to new sxtopdf version and make use of the -i inputfile parameter
- fix build on openSUSE 10.2
- fix iChain authentication dialog appearing behind the Fate window
- fixed usercheck for new features
- default to keeper.novell.com
- remove SSL certificate hack
- do not process socket notifiers at that point
- remove "@novell only" and migration code
- always parse both the body and the header for error messages
- remove "tested" state
- be more clear about the meaning of the buttons in the check results dialog
- Issue a warning when the requesting party of a feature is about to be changed.
  fate305010
- fix clicks on email links
- show a message in the diff output if the features are identical
- New contextual error messages
- clean up handling of relationtypes
- Make all roles visible without a scrollbar
  fate304906
- remember the last role used
  fate304906
- remember last used relation
  fate305013
- work around annoying iChain which rewrites our custom http headers
- remove "tested" state
- be resistent against whitespaces in the id-query field
- tell what resources failed the md5sum check
- add partner images
- Force iChain to not cache any metafile
- fix taborder in the relation editor
  fate304958
- do not show the editor on startup when there is nothing to show
- ask, if the user really wants to discard the comment
  bnc399249
- update welcome screen
- fix stupid restock-behaviour of reloading all current features
- fix parsing of "rejected" person
- add migration code which will automatically set the new keeper url.
- better formatting for the error messages
- disable cancel-button on the first start
* Thu Jun  5 2008 aduffeck@suse.de                   
- version 1.3.11.3
- fix Fate hanging on start when a wrong keeper is set.
- Optimized "My Features" query which is executed way faster than the current
  one.
* Mon May 26 2008 aduffeck@suse.de
- version 1.3.11.2
- Do not allow empty comments. bnc391803
- Show an error if caching is disabled and the user wants to show a diff of
  the current feature. bnc391804
- Make it possible to send a mail to the responsible people of the features
  of a query. fate303750
* Wed Apr 23 2008 aduffeck@suse.de
- version 1.3.11
- Fix restocking when the feature was not saved yet
- fix build on sles9
- update changelog
- Respect the "display" property
- update item count when filtering for modified items
- Do not allow duplicate actors bnc359290
- fix documentation build/install
- updated docu and release readme
- Rename "Partner benefit / Business case" to "Business case (Partner
  benefit)" fate303443
- Add a script for generating a fate.pdf from the docbook sources. Needs
  the docbook-toys package installed
- Always preserve comment privacy setting when a comment is edited. bnc362805
- Prepare for a html version of the process and policies help and make it
  possible to print it.
- Use the html file from the keeper
- use a .ui-file for the configuration dialog
- advertise the "Process, Roles and Policies" documentation when Fate is
  run for the first time fate303455
- Add a GUI for ordering the parts of the pretty view fate303478
- Add a "Cancel" option to the "Save now or later dialog" which will
  return to the original feature fate303324
- Enforce that a comment is made, when the PM-Priority is downgraded from
  Mandatory/StopShip fate303456
- Add a "Show Diff" button which shows the changes that were made to the
  feature
- disable diff buttons when there are no changes yet
- Add "Business Case" field to the New Feature-Dialog
- Use a .ui file for the dialog
- Fix the products tooltip fate303477
- "Partner" -> "Requesting Party" fate303477
- Disable Diff button for new features
- Fix disabling the save button in order
- remove some debug messages
- properly react to changed valuelist
- fix documentation when opened from within khelpcenter. i have no idea
  why it works when it is opened from fate at all.
- Add a item delegate for the relation types, showing both the name and
  the description for better understanding of the different types.
- Add a dialog for editing the relation tree
- Do not allow to edit the relation tree in offlinemode
- Implement DialogSize::remember() and DialogSize::restore() for QDialogs.
- use the names for the tooltips
* Tue Feb 19 2008 aduffeck@suse.de
- version 1.3.10.1
- Always preserve comment privacy when a comment is edited (bnc362805)
* Tue Feb  5 2008 aduffeck@suse.de
- version 1.3.10
- restructuring++
- fix crash. do not install convenience libraries
- add first unit tests
- Add convenience method parseProduct
- add test for Product
- forwardport: invalidate caches before anything can be loaded from them
- add test for ProductParser
- add some checks for null pointers
- fix enabling/disabling the query action
- On start up, download information about the client from the keeper. This
  allows us to show a message about a new Fate version with a download
  link, for example. It also makes it possible to lock out specific
  clients.
- Add "Client Information loaded" to the startup sequence
- automatically build libfate tests on "make check"
- first bug found with unit tests: Fix parsing of Relation->Description
  field
- complete FeatureParserTest
- fix crash on saving new features
- allow to lock clients
- Do not activate the signal inside the QMapIterator loop. During the
  signal, the underlying QMap can (and does) get cleared which results in
  a crash.
- Allow to store a query without opening the "Edit XQuery"-dialog
- Allow to cancel the save process when an error has occured.
- Fix weird resizing of the Stored Queries-dialog.
  bnc352919
- Fix duplicate product entries in statistics view's combobox
  bnc352907
- Make it possible to export the feature table.
  bnc279162
- harden the caches by cleanly separating the modified/new items from the
  originals in the cache. That also fixes some issues wrt offline mode,
  such as "Reload Feature".
- Structurize the MainView initialization, so that it is guaranteed, that no queries will be made
  before the products have been loaded.
- make the actorlist smaller and remember the size of the dialog.
  fate303054
- init splitter in General tab with sane values.
  fate303053
- Allow to define an arbitrary stored query as the startup query
- make sure that the feature list is cleared after a query has failed.
- clear the editor when the view is cleared
- Enable clearing the html view. Apparently something has changed in
  between so that the welcome page is no longer automatically cleared().
- Show error messages if a product or milestone was not found and is thus
  removed from the feature, so that the user can react accordingly.
- Allow to filter modified features in the list.
  fate303357
- Add "Integrity checks loaded" precondition and only enable the client if
  it is fulfilled.
- Do not bark if no setting was ever stored.
- Show error messages if the XCL file is missing or malformed and do not
  allow to save the feature in that case.
- Show error message if the XCL file is malformed
- fix readonly mode
- immediately disable the save buttons after they were clicked and
  re-enable if the save process failed or there are other modified
  features. This prevents that users save a new feature twice.
  Also clean up some unneeded indirections.
- update .desktop file
- use cmake
- install a fate:// protocol handler
- Offer setting infoprovider when making a comment
  fate303417
- Add a "add attachment" link to the pretty view to better promote that
  feature
- Do not show "Schema revision change detected" on first start
- KMessageBox::detailedError -> KMessageBox::errorList which is resizable
- Add a "Process and Policies" help entry
  fate303434
- make sure the save buttons are always enabled/disabled correctly
- fix default splitter sizes
- Fix restocking when the feature was not saved yet
* Tue Jan 15 2008 aduffeck@suse.de
  * version 1.3.9 patchlevel 3
- Fix recursive iterator loop
- Fix requester priority check
- Disable Query action when offline mode is active
* Tue Jan  8 2008 aduffeck@suse.de
- version 1.3.9 patchlevel 1
- fix sorting of products according to their dates
* Wed Jan  2 2008 aduffeck@suse.de
- version 1.3.9
- Fix weird behaviour when editing the products of a feature. (Bugzilla #337372)
- Fix parsing the date of the comments and the relation when importing a feature from bugzilla
- fix reload feature
- Return the roles according to the sort order.
- Do not silently overwrite attachments with the same name
- Add a private attribute to the relation
- Create private comments when the relation is marked as private.
- Do not allow to add an attachment to a new feature, that was not save
  yet. At this time, the id of the feature is not known, so the attachment
  can not be put in the right directory.
- add filename to comments
- really don't execute the query in offlinemode
- fix lost new features after offlinemode
- Do not try to save the attachment again if only the title or privacy
  setting was changed
- Change ID Query. (Bugzilla #214375)
- Automatically add/remove a feature/duplicate relation when the feature
  is marked as an duplicate
- add application icon for fate
- Add support for bookmarks. (Fate #303025)
- Parse product dates featureOpen, featureDeadline and productReleased.
- Sort products according to their dates. (Bugzilla #256451)
- Show the fatename in the title of the MyFeatures query
- replace the "Only Whiteboards containing..." query option with a "Only
  Features where x contains y" option. The list of fields that can be
  queried is fetched from the keeper dynamically. (Bugzilla #190335)
- Make the cache hotswapable.
- Let the MetaManager reload the metafile when the keeper changed.
  Different keepers may have different metafiles.
- Add a "Set Defaults" button (Bugzilla #337233)
- fix encoding issues (Bugzilla #335616)
- show the relationtree only when it is enabled in the config
- fix cancel query when the parser is running
- fix the status message when a query was canceled
- A nicer progress bar. When the size of a query is not known it now
  indicates that with a little bar running from the left to the right and
  back. No KIO dialogs are shown anymore with downloads.
- Get rid of the "Waiting for server response" phase
- Allow to restock the current featureset with single features, e.g. when
  a reference to a duplicate feature is clicked which was not loaded yet.
  This commit also finally makes the selection of the chosen feature in
  the listview work.
- Show a message when restocking is not possible
- Show a message when offlinemode is not available
- Disable caching, which can break reload feature, for example. (Bugzilla #271806)
- support for some more relation types
- Do not query the relations when offlinemode is active
- do not try to download the products when the offlinemode is active
- save the correct featureset for the offline mode
- Warn that the feature set will no longer match the result of the current
  query, if a feature is restocked, for example when a link to a feature
  was clicked.
- Load all products from the cache when started in offline mode
- add a "Product list loaded" precondition. loading the products might
  take a while if the list is large
- disable feature query lineedit in offline mode
- show new feature id after a new feature was saved
- add new features at the end of the list
- select new features in the listview
- only show the tree when TreeEnabled=true in [General]
- Delay the execution of the query until the product list was loaded. This
  fixes a problem in the offline mode where the loaded features lost their
  products.
* Tue Oct 23 2007 aduffeck@suse.de
- Version 1.3.8
- Fix actor editor dialog (Bugzilla #292678).
- Always show correct display names in actor list editor.
- Cached queries
- Rename status "Eval ProdMgr" to "Eval PM" to make it less likely to be confused
  with "Eval PrjMgr".
- Make caching configurable in the config dialog.
- Offline mode now uses the query caching instead of its own data storage.
- Make Cache an abstract base class and create FileCache inheriting from
  it. This allows to create different backends for the cache.
  The FileCache creates one file per feature.
- Add and use SQLiteChache, a cache backend which stores the features in a
  SQLite database. Requires the qt3-sqlite module to be installed.
- report progress while reading the cache.
- Refactor progress management. It is now done with a central
  ProgressManager singleton, which allows to remove a bunch of signals and
  slots.
- Do not block the GUI when the parser runs and also show the progress in
  the progressbar.
- Do not recreate features that are already in memory.
  Features that are already parsed in the memory and that are also
  required in the new query are now kept instead of deleting and creating
  them again. This rapidly increases performance for similar queries.
- Make "Cancel Query" work with cached queries.
- Major refactoring of the feature management. It is now
  possible to edit several features at the same time. They are then saved at once
  when the save process is triggered. It is also possible to close the
  application and continue with the current state if caching is enabled.
  This fixes #191955 and #210168.
- If there are modified features and they need to be saved, they are now
  presented in a dialog where the user can select the features that should
  be saved. This makes is transparent which features were changed and
  which of them were already saved and so on.
  If the featureset is about to change (e.g. because a new query is done)
  the changed features can only be saved on the keeper, if not however,
  the features can also be saved in the cache if caching is enabled. This
  allows to keep modified features and finish them the next time fate is
  started.
- Fix some OfflineMode issues.
- Workaround nasty Qt bug where widgets break the parent's layout system.
  http://trolltech.com/developer/task-tracker/index_html?id=94203&method=entry
- Port the SQLiteCache to the pure sqlite3 lib without the Qt layer, which
  in Qt3 - is not capable of blobs.
- Keep the reload action enabled even in offline mode, which is now
  possible with the caches. This fixes bug #197752.
- Allow to edit items by double-clicking on it in listedits, e.g.
  actorlist or relationlist
- Ask the user to save if a feature was modified and another one gets
  selected. It is also possible to save the feature later.
- Make the statistics view look like the feature view with the new css.
  The css should really be put on the keeper instead.
- Detect urls in fate entries. This fixes #134955
- Show the product name in the "Delete product" action #190124
- Allow &lt;blubb&gt; in richtexts.
- Warn when the user tries to remove a product which has the status
  'rejected'. #270228
- Warn the user if the query will always return no features due to the
  status check.
- Disable category items in the treeview which do not contain any
  features. #120599
- Distinguish between "Save current feature" and "Save all modified
  features". Therefore a "Save all" button was added to the editor and the
  view.
- Add some space between the "Save all" and "Save" button
- Fix #289254 where the upper left pull-down menu in the priority table is
  not selectable if there are more than one columns and it is the first cell
  that gets selected
- Use the SQLiteCache also for the products if it is available.
- Ability to store file attachments on a webdav server added.
- Make it possible to cancel a query also when the parsing has already
  started.
- update admin dir
- Save a single feature as it is intented to.
- Do not reload a feature from the cache after it was saved. That fixes a
  bug, where a feature could only be saved once.
- Validate product before adding it.
- Add a comment when an attachment was created.
- Add a comment when an attachment is changed.
- Create the comments in the SimpleEditor. Also add a comment, when an
  attachment was deleted.
- Allow the user to choose to either save the attachment or open it when
  the link was clicked. If the file should be opened, it is now copied
  into a temporary file first, which enables the xdg-open tool to
  determine the mimetype and open it with the proper application.
- Highlight own role in Fate. Fate #302343
- Use transactions when creating the cache, which reduces the cache
  buildup time from ~60s to ~10s.
- Use the configured stakeholdername for queries instead of the one
  generated from the login name in the first query
- Add "Do not ask again" option to the save-now-or-later question
- Add a command line option which allows to query for a specific feature.
- Add a LineEdit to the toolbar which allows to directly query for a
  specific feature or several features separated by commas.
  This commit also extends the commandline option and dcop interface to
  query for a comma-separated list of features.
- use schema v10
- Fix encoding issues (#335616)
- Invalidate local caches if a schemarevision change was detected
- 9.3 is no longer supported
* Thu Jul 19 2007 cschum@suse.de
- Version 1.3.7.2
- Fix regression in editing of actors (Bugzilla #292678)
* Tue Jul 17 2007 cschum@suse.de
- Version 1.3.7.1
- Load all meta data on first start and make sure that all data is fetched
  before the user can use the parts of Fate which depend on the data
  (Bugzilla #287689).
- Fix build and add factory to standard build targets.
- fix windows with 5 times more width than the desktop.
  The text content should fade out to show this limit ...
- Build parallel.
- Fix query for priorities which aren't set (Bugzilla #288443).
- Include "Evaluation by Product Manager" in "My Features" query (Bugzilla
  [#288093]).
- Add statistics for "Unconfirmed" status (Bugzilla #288090).
- Remove support for obsolete value list format.
- Track progress in startup sequence and show it in a status pane.
* Tue Jun 19 2007 cschum@suse.de
- Version 1.3.7
- Use more efficient XQuery for text search.
- Don't check email addresses twice (#276468).
- Fix crash when editing actor without doing changes (#276463).
- Export all features of a query by default and offer single feature export as a
  configurable option.
- Adapt progress handling to streaming XML generation on Keeper which doesn't
  include the size information at the beginning of the response anymore.
- Take available role values from valuelist from keeper.
- Use display names of roles in GUI
- Rename "Eval Teamleader" to "Eval EngMgr".
- Rename "teamleader" to "engineering manager" (#226078).
- Install images used in css
- Parse and show milestone.
- Use new product selector which also reads NPP data if available.
- Remove "Query All" from toolbar.
- Add product viewer.
- Require feature schema version 9
- Handle remembering of dialog size more robustly.
- Use bulk download to get products and cache it locally.
- Add support for relations (Bugzilla #119201).
- Add relation to Bugzilla when importing a Bugzilla entry.
- Correctly import comments from Bugzilla
- Map Bugzilla product to Fate product if available
- Add status "Evaluation by product manager".
- Remove "research" status.
- Show warning when query URL gets too long (Bugzilla #283763).
- Don't add requester twice (Bugzilla #275089).
- Sort actors by roles using a order based on temporal flow of the request
  (Bugzilla #272655).
* Mon May 14 2007 cschum@suse.de
- Version 1.3.6
- Updated documentation.
- Update admin dir.
- Add initial version of Bugzilla import.
- Added the first version of Fate logo on the welcome page.
- Show correct maximum schema revision in dialog.
- Adapt to schema change of role element.
- Show in comment dialog which infoprovider will be removed when the "provides
  info" checkbox is checked (#255792).
- Remember size of comment dialog.
- Add support for "unconfirmed" status.
- Warn when adding comment and being set as infoprovider but not checking the
  "provides info" box (#262338).
- Make offline mode more visible (#269785).
- Fix truncation of rich texts (#270140).
- Alternative product list editor, disabled by default for now.
- Move creation of KIO jobs to central location, so that user agent is
  consistently sent.
- When resource loading failed, force reload with next request.
- Preserve userid and company fields in person elements.
- Remove partner role (#223175).
- Check email not only when adding new actor, but also when editing existing
  actor.
- Migrate email addresses on startup if necessary.
- Show error message, when parsing of feature on import fails.
- Use correct default email address in query dialog.
- Show all available roles in query dialog.
- Load partner and category list also when no query has been done yet (#249275).
* Wed Mar 28 2007 cschum@suse.de
- Version 1.3.5
- Disable query log by default. Can be activated by putting DeveloperMode=true
  in the [General] section of the Fate config file at
  $KDEHOME/share/config/faterc.
- Sort products alphabetically in product selector of statistics view (#256449).
* Tue Mar 20 2007 cschum@suse.de
- New version 1.3.4.9 (Beta)
- Refer the duplicate check to the status field instead of the priority.
  (#244115)
- Automatically replace empty lines with paragraph breaks and lines
  starting with '*'s with lists. (#134946)
- Display <none> as actor in the statistics, if none was set. (#245445)
- Replace the DOM-Parser with a SAX-Parser. That significantly reduces
  memory consumption of Fate. (#120595)
- Show a hint about the automatic conversions fate does in the richtext
  edits. Show a link that opens a detailed explaination. (#246260)
- Escape <'s and >'s that are not part of html tags.
- Make the warnings about not opened/closed/post-deadline features more
  strict (#246227)
- Make it possible to select other features while commenting a feature.
  (#247343)
- Show feature id and title in the comment dialog.
- Try to convert markdown syntax only if there are no html tags (#248896)
- Apply Gerald's patch, making "New Feature" dialog more consisent.
  (#248921)
- Make Fate scriptable with dcop.
- Fix automatic tag generator. (#251571)
- Adjust width of newly added product columns (#253462).
- Show keeper name in caption.
- Correctly remove actors (#248912).
- Add help text for partner combo (#250191).
- Add newlines after paragraphs (#255617).
- Be less strict with allowed characters in id line edit (#248855).
- Don't offer non-existing products anymore (#251186).
* Fri Mar  9 2007 stbinner@suse.de
- fix build (new icon location check)
* Wed Feb  7 2007 cschum@suse.de
- New Version 1.3.4
- Really cancel going offline if the user pressed cancel. (#225716)
- Avoid warning that the server certificat could not be authenticated.
  (#220308)
- Add a progressbar, showing the progress of the query being executed
  (#119818)
- Add a cancel button next to the progress bar. (#119818)
- Go Offline again if the switch from Offline to Online fails. (#225715)
- QTabWidget->KTabWidget. That makes it possible to switch the tabs using the
  mousewheel. (#119190)
- Avoid emitting dangling pointers. (#216520)
- Don't delete the first entry in the partner combo. (#211641)
- Prohibit closing a feature as "tested" if there is an infoprovider set.
- We need to emit metaDataLoaded() also when the metadata was not changed
  on the keeper. (#231177)
- Remember the selected products for the "My features" query. (#206960)
  The KAction has become a KActionMenu with a sub action for changing the
  products.
- Update admin directory.
- Add a roles pane to the "New Feature" dialog. (#191968)
- Refresh metafiles only when the revision was changed. (#224835)
  As a side effect of this change, the error message of a failed
  connection appears only once. (#214343)
- Show the features that belong to the category when the category was
  selected in the treeview.
- Always reload metadata if the keeper didn't send the meta-revision
  header. (#237585) (#235107)
- Warn if a duplicate feature has a different partner set (or if fate
  doesn't know because the other feature is currently not loaded) (#231911)
- Added statistics view. (#233597)
- Applied Geralds patch that adds Andre to the authors list.
  This fixes #241057
- Add query field to search for features that were changed in the x last
  days/weeks/months/years. (#130706)
- Allow vertical resizing below 768 pixels. (#241531)
- Show intro in the category view. (#127497)
- Default the mail address to @novell.com.
  Change existing @suse addresses on startup. (#237083) (#240547)
- Add query option "<= important" (#236734)
- Add "stopship" to ">= important" and ">= desirable".
- First steps towards hierarchical features. It's disabled for now. To enable it
  add an entry RelationsEnabled=true to the Relations section of the faterc
  file.
- Fix bug where the progressbar stalls at 90%% when a query fails.
- Remember size of the CheckResultsDialog. (#244254)
- create new features with SCHEMA_REVISION_MAX so that no extra conversion
  on the server is needed
- Improve usability of the QueryDialog. It also remembers the size if it gets
  resized. (#244999)
* Wed Nov 29 2006 freitag@suse.de
- New Version 1.3.3
- Add tooltips to product- and category-textedits.
- removed dots from menu entry (#216163)
- Add "Edit Queries..." action to the stored queries menu. (#127767)
- Add a feature table view (See menuitem File/Show Feature Table). (#120105)
  Product and priority is configurable.
- Add ">= important" and ">= desirable" options for querying priorities.
  (#215815)
- Set saved flag only when it was successful. Also detect lower level
  errors. (#217011)
- Check for products that are closed, passed a deadline or are not opened
  yet. (#171025)
- Avoid duplicate entries in the actors popup menu. Initial patch by
  Gerald.
- Don't remember partner in new feature dialog.- Add checkpoints facility
  for easier correlation of program flow and massif results.
- Adopt new priorite 'stopship'
- Add a check for the requester priority being not 'stopship'
- Emit a warning if the user tries to add a role with an mail address
  different from @novell.com addresses. (#187665)
- Allow partner roles to have a not-@novell.com mail address.
- Add checks for teamleader and developer. (#217931)
- Redisable debug output.
- Convert the actorlist to contain novell-entries instead of suse entries
- Convert ximian correctly
- Remove not needed debug output.
- Do no longer confuse Gerald. (#223220)
  Therefor the Responsibles check has been splitted into one check for
  each role.
- Add the possibiliy of showing warnings to the CheckResultsDialog.
  (#217931)
  If there were warnings the user can decide to still save the feature or
  cancel and change the feature.
- Add a warning if the feature is in state 'Ready' and there is no
  developer set. (#217931)
- Make Projectmanager priority mandatory for "Implementation" and "Ready"
  and emit a warning if it's missing in "Eval by teamlead" state. (#217929)
  Also fix teamleader detection.
* Thu Nov  2 2006 freitag@suse.de
- Update welcome text regarding "My Features" query.
- Don't call sxtopdf with '-q' parameter if no query is given
- Allow searching for more than one product at once in the query dialog.
- Render umlauts in comments correctly (#135655)
- Use https to access keeper by default.
- Add dialog for stored queries which allows renaming, deleting and
  executing queries. (#127767,#130708)
- Add Toolbar action to reload current query. Patch from Stanislav
  Visnovsky. (#200182)
- Show an error if the user tries to store a query which already exists.
  (#130708)
- Verify that all products are valid. (#212944)
- Fix bug, where the priority was always set to 'neutral'.
- Add a "New Feature" dialog which allows to easily create new features.
  (#130240)
- Select Novell as partner the first time the dialog is shown. Then the
  last used partner is remembered.
- Collect uncategorized items in a dedicated folder.
- Update category list and tree when a feature was changed. (#128338)
- Use desktop-launch to start browser or mail program.
* Wed Sep 20 2006 dmueller@suse.de
- use RPM_OPT_FLAGS
* Wed Sep 20 2006 cschum@suse.de
- Version 1.3.1
- Bug #130988 comment #11: Implemented radio buttons where user can choose
  whether to query for features with infoprovider set, unset or both.
- Added query for "My Features"
- Added a config option for the startup query and enhanced the dialog
- Remove the infoprovider cleanly from the feature object and
  also from the editor listview. This fixes bug #204097
- Consider duplicate as closed (#205976)
- Query "My Features" on startup by default.
- Make it possible to select products for "My Features" query (#203770).
- Always enable editor when creating new feature (#135799).
- More consistent naming of toolbars (#189565).
* Thu Aug 31 2006 cschum@suse.de
- Version 1.3
- Rename "Add Category" action to "Assign Category" (#201194).
- Add shortcut "CTRL+R" for reloading feature (#199429).
- Add roles qareviewer and qatester (#135315).
- Prevent setting feature to duplicate of itself (#189468).
- Don't allow empty partner and default to Novell (#200823).
- Don't allow to close a feature which has an infoprovider set (#201449).
- Don't install icon on the desktop (#130255).
* Fri Aug 25 2006 cschum@suse.de
- Version 1.2.9.4 (Beta)
- Fix references data loss (#199110).
* Fri Aug  4 2006 cschum@suse.de
- Version 1.2.9.2 (Beta)
- Remember query associated with offline profile.
- Fix links in category view.
- Don't ask for offline profile on startup, if there is only one.
- Fix bug which set features to modified when switching to
  category view.
* Thu Aug  3 2006 cschum@suse.de
- Version 1.2.9.1 (Beta)
- Implemented offline mode.
* Wed Jul  5 2006 freitag@suse.de
- Version 1.2
- added richtext validation to the client for texts like description
  etc and comments. No more text loss any more.
- reorganised feature checks: All checks are done now and the results
  are presented in an overview providing dialog.
- Improved Feature Duplicate handling.
- changes are updated in the view now instantly
- Fixes in meta data handling
- Fixed some wordings
- under the hood:
  * changes of the xml parsing and xml generation
  * more consolidated data management.
  * better comment handling
- many small bug fixes.
* Thu May 18 2006 cschum@suse.de
- Version 1.1.6
- Added the validation rule requiring a requestor priority (#120593).
- Added toolbar buttons and menu entries for adding persons, adding categories
  and adding products (#119611).
- Error dialog of export pdf function now contains a 'detailed' button, which
  displays sxtopdf's output when pressed (#128705).
- Added context menu for removing products in the priority table.
- Edit architecture field with single mouse click instead of double mouse click
  (#134143).
- Implement import of single features from XML files (#170585).
* Fri Mar  3 2006 freitag@suse.de
- Version 1.1.5
- added check to see if there is a product at all especially for
  new features (Bug #143277)
- added check to avoid rejection of TPM mandatory features (Bug #143278)
- Added context menu entry to the product table that opens
  a small window that displays the reject reason for a product.
- added edit possibility for newly created comments before they're
  saved, link to the html xslt added.
- Fixed generation of the comment in-reply-to combobox
- various server fixes.
* Mon Nov 28 2005 cschum@suse.de
- Version 1.1.4
- Get product list from keeper.
- Convert all emails to lowercase that come out of the actor editor
- Fixed a bug with editing authors: changing the author to
  an already existing one removed the entry completely.
- Fixed regex for checking emails (#135381).
- Fix saving of references (#135540).
- When saving fails show in the dialog where the backup file is, so
  that it's possible to recover the data (#134933).
* Fri Nov 18 2005 cschum@suse.de
- Version 1.1.3
- Added text completetion for actor editor
- Avoid duplicate entries in the actor list where email and role are equal.
- Load XSLT and CSS for creating the HTML view for a feature and the tree
  definition for the hierarchy view from keeper (#132690).
- Add the user as default requester for a new feature
- Don't set a default value in id query dialog (#127580)
- Email check in actor dialog added
- Add support for querying texts in titles and descriptions.
- Add support for showing diffs.
- Give user feedback while loading the style sheet.
- Set initial focus on text edit of comments dialog.
- Add save button on view tab.
- Disable save buttons when feature isn't modified.
- Don't move focus to editor, when navigating through features with cursor keys
  (#119149).
- Remove "edit" entry from context menu of categories list (#121920).
- Clarify "save feature?" dialog (#130241)
- More sane initial window size for document source viewer.
- Fix going back in history to categories (#91171).
- Prevent double loading of features and categories (#91171).
* Thu Nov 10 2005 cschum@suse.de
- Version 1.1.2
- Allow to set product manager priority for features with status "new".
* Wed Nov  9 2005 cschum@suse.de
- Version 1.1.1
- Require that a requester is set.
* Wed Nov  9 2005 cschum@suse.de
- Version 1.1
- Added neutral priority (#129637).
- Added infoprovider role (#130988).
- Added additional validity checks (#131433).
- Clear category selection in editor when switching between features (#130711).
* Wed Nov  2 2005 dmueller@suse.de
- don#t build as root
* Thu Oct 27 2005 cschum@suse.de
- Version 1.0.3
- Don't delete discussion when validation fails (#130779).
- Make it build on 9.1/SLES9/NLD9.
* Tue Oct 25 2005 cschum@suse.de
- Version 1.0.2
- Show decent error message when no criteria are selected in query dialog.
- Associate upload jobs with main window.
- Ask before quitting when there are unsaved changes (#129036).
- Multi-line text edit for reason for rejection.
- Add "Remember Query" button to query dialog (#128461).
- Add keyboard shortcuts for zoom actions (#130184).
- Provide option to also skip duplicate features in query.
- Removed state variables from PriorityTable to reflect column
  to product mapping correctly
- Set column of the product view to full width to avoid the
  problem that deselects all products if clicking beside the
  listview (rf & mkraft)
- Show usecase content in HTML view.
- Show documentation status and impact in HTML view.
* Wed Oct 19 2005 cschum@suse.de
- Version 1.0.1
- Implemented removing of products (#119621)
- Preserve attributes of "rejected" status on save.
- Fix "skip done and rejected" query if no specific product is selected.
  (#129020)
* Tue Oct 18 2005 cschum@suse.de
- Version 1.0 - first release for production use.
* Thu Oct 13 2005 cschum@suse.de
- Version 0.9 - first release candidate.
* Thu Sep 15 2005 freitag@suse.de
  Update to version 0.6 - beta version
- Comments are not longer posted by freitag@suse.de
- Username, function and server user are now in the configuration
- other bugfixes
* Mon Sep 12 2005 freitag@suse.de
  Update to version 0.5.4 - beta version
- Changed GUI slightly, removed all query buttons and created
  KActions from them to be more KDE complient with Toolbars and
  Menus
- Added a person search dialog
- Added a xquery dialog
- Fixed writing of new features
- added more intelligent authentication dialog (still todo)
  It takes the logged in user now and adds a @suse.de to it,
  which is buggy (FIXME)
- Fixed update after write
- Fixed the Feature listview (duplicate entries)
- Fixed the xslt to show versioningsummary + revision correctly
- more minor fixes
* Wed Aug 31 2005 freitag@suse.de
- update to version 0.5.2 - beta version
* Mon Jun  6 2005 cschum@suse.de
- Initial version.
